module.exports = defineTest({
	description: 'detects side-effects in complex call expressions'
});
